@@ -1,6 +1,7 @@
 import traceback
 
 from sys import exit
+from time import sleep
 from ast import literal_eval
 from typing import Any, Dict
 from cosecurity_amqp_lib.logger import logger
@@ -11,10 +12,13 @@ class Consumer(BaseClient):
     """
     queue consumer with a general handler to handle posted messages
     """
-    def __init__(self, name:str) -> None:
+    def __init__(self, name:str, on_error_restart_consumer:bool=True, wait_time_to_restart:int=20) -> None:
         super().__init__()
         self.queue = self.get_service_queue(name)
         self.name = name
+        self.on_error_restart_consumer = on_error_restart_consumer
+        self.wait_time_to_restart = wait_time_to_restart
+        self.restart_count = 0
         self.handlers = {}
 
     def register(self, handler:Any) -> bool:
@@ -42,12 +46,27 @@ class Consumer(BaseClient):
             logger.info(f'{self.name} initialized')
             self.channel.start_consuming()
         except:
-            self.channel.stop_consuming()
+            logger.error(traceback.print_exc())
+            self.stop(arguments)
+
+    def stop(self, arguments:Dict[str, Any]=None):
+        try:
             self.channel.close()
             self.connection.close()
-            logger.info(f'{self.name} finished')
-            exit()
-            
+        finally:
+            if self.on_error_restart_consumer:
+                self.restart(arguments)
+            else:
+                logger.info(f'{self.name} finished')
+                exit()
+
+    def restart(self, arguments:Dict[str, Any]=None):
+        self.restart_count += 1
+        logger.info(f'{self.name} restarted - {self.restart_count}')
+        sleep(self.wait_time_to_restart)
+        self.to_connect()
+        self.start(arguments)
+
     def _callback_method(self, ch:str, method:str, properties:Dict[str, Any], body:str) -> None:
         try:
             message = self._binary_to_dict(body)
