@@ -88,11 +88,30 @@ class FaceDetectionStub(Stub):
             content={}
         )
 
-    def to_recognize(self, detected_object_id:int, image_key:str) -> None:
+    def to_recognize(self, detected_object_class_id:int) -> None:
         self._send(
             primitive='to_recognize',  
             content={
-                'detected_object_id': detected_object_id,
-                'image_key': image_key
+                'detected_object_class_id': detected_object_class_id
+            }
+        )
+
+class VehicleDirectionDetectionStub(Stub):
+    def __init__(self):
+        super().__init__(
+            destination='vehicle_direction_detection'
+        )
+
+    def to_train(self):
+        self._send(
+            primitive='to_train',  
+            content={}
+        )
+
+    def to_predict(self, detected_object_class_id:int) -> None:
+        self._send(
+            primitive='to_predict',  
+            content={
+                'detected_object_class_id': detected_object_class_id
             }
         )
\ No newline at end of file
